@@ -1,27 +1,3 @@
-//     bindet - Fast binary file type detection
-//
-//         The MIT License (MIT)
-//
-//      Copyright (c) Obliter Software (https://github.com/oblitersoftware/)
-//      Copyright (c) contributors
-//
-//      Permission is hereby granted, free of charge, to any person obtaining a copy
-//      of this software and associated documentation files (the "Software"), to deal
-//      in the Software without restriction, including without limitation the rights
-//      to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-//      copies of the Software, and to permit persons to whom the Software is
-//      furnished to do so, subject to the following conditions:
-//
-//      The above copyright notice and this permission notice shall be included in
-//      all copies or substantial portions of the Software.
-//
-//      THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-//      IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-//      FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-//      AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-//      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-//      THE SOFTWARE.
 //! Description module
 use crate::matcher::RelativePosition;
 use crate::types::FileType;
@@ -135,6 +111,9 @@ impl FileTypeDescription for FileType {
                 FileType::Rar5 => Some(8),
                 // https://www.gnu.org/software/tar/manual/html_node/Standard.html
                 FileType::Tar => Some(257 + 8),
+                FileType::Lzma => Some(1),
+                FileType::Xz => Some(5),
+                FileType::Zst => Some(4),
                 // https://www.w3.org/TR/PNG-Rationale.html#R.PNG-file-signature
                 FileType::Png => Some(8),
                 // https://en.wikipedia.org/wiki/JPEG#Syntax_and_structure
@@ -166,6 +145,7 @@ impl FileTypeDescription for FileType {
                 FileType::Xcf => Some(10),
                 FileType::Gif => Some(4),
                 FileType::Bmp => Some(2),
+                FileType::Iso => None,
             }
         } else {
             match self {
@@ -218,6 +198,7 @@ impl FileTypeDescription for FileType {
                 FileType::Rar => Some(MEGABYTE),
                 // https://www.rarlab.com/technote.htm
                 FileType::Rar5 => Some(MEGABYTE),
+                FileType::Iso => Some(32769 + 5),
                 _ => None,
             }
         } else {
@@ -226,7 +207,7 @@ impl FileTypeDescription for FileType {
     }
 }
 
-/// Coerce to the maximum value of all [filetypes](FileType::variants) using [`f`][F] to compute
+/// Coerce to the maximum value of all [filetypes](FileType::variants) using `F` to compute
 /// the values to compare between.
 fn coerce_file_types_at_least<F>(f: F, variants: &[FileType]) -> Option<(usize, Vec<FileType>)>
 where
