@@ -1,28 +1,3 @@
-//     bindet - Fast binary file type detection
-//
-//         The MIT License (MIT)
-//
-//      Copyright (c) Obliter Software (https://github.com/oblitersoftware/)
-//      Copyright (c) contributors
-//
-//      Permission is hereby granted, free of charge, to any person obtaining a copy
-//      of this software and associated documentation files (the "Software"), to deal
-//      in the Software without restriction, including without limitation the rights
-//      to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-//      copies of the Software, and to permit persons to whom the Software is
-//      furnished to do so, subject to the following conditions:
-//
-//      The above copyright notice and this permission notice shall be included in
-//      all copies or substantial portions of the Software.
-//
-//      THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-//      IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-//      FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-//      AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-//      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-//      THE SOFTWARE.
-
 //! Fast binary file type detection
 //!
 //! `bindet` provides a fast and safe binary file detection even for large files.
@@ -34,7 +9,10 @@
 //!
 //! - Zip
 //! - Rar (4 and 5)
-//! - Tar
+//! - Tar (uncompressed)
+//! - LZMA
+//! - 7zXZ
+//! - Zst
 //! - Png
 //! - Jpg
 //! - 7-zip
@@ -62,6 +40,7 @@
 //! - Xcf
 //! - Scala Tasty
 //! - Bmp
+//! - Iso
 //!
 //! ## First Step
 //!
@@ -128,13 +107,30 @@
 //!
 //! assert_eq!(detect, expected);
 //! ```
+//!
+//! ### Features
+//!
+//! #### `mime`
+//! Enables conversion from [`FileType`][`types::FileType`] and [`FileRootType`][`FileRootType`] to
+//! `Mime` by implementing `TryInto<Mime>` trait,
+//! there is no need to `use` any additional module, just enable the feature.
+//!
+//! #### `mediatype`
+//!
+//! Enables conversion from [`FileType`][`types::FileType`] and [`FileRootType`][`FileRootType`] to
+//! `MediaTypeBuf` by implementing `TryInto<MediaTypeBuf>` trait,
+//! there is no need to `use` any additional module, just enable the feature.
+//!
 #![feature(test)]
 use crate::description::FileTypeDescription;
 use crate::matcher::{FileTypeMatcher, RelativePosition, Step, TestResult};
-use crate::types::FileType;
+pub use crate::types::FileRootType;
+pub use crate::types::FileType;
 use std::io::{Read, Seek, SeekFrom};
 use std::prelude::rust_2021::TryFrom;
 
+#[cfg(any(feature = "mime", feature = "mediatype"))]
+mod conv;
 pub mod description;
 pub mod matcher;
 pub mod types;
@@ -241,7 +237,7 @@ where
 /// may be reported with [`FileTypeMatch.full_match = false`](FileTypeMatch) signaling a probable
 /// match.
 ///
-/// This is a less reliable version of [`check`](check), but with guaranteed `O(1)` time complexity,
+/// This is a less reliable version of [`detect`], but with guaranteed `O(1)` time complexity,
 /// in other words, it takes the same time to check small files and larger files.
 ///
 /// Since different [FileType] detection implementations receives the same data slice, it may produce
@@ -257,13 +253,13 @@ where
 /// may be reported with [`FileTypeMatch.full_match = false`](FileTypeMatch) signaling a probable
 /// match.
 ///
-/// This is a less reliable version of [`check`](check), but with guaranteed `O(1)` time complexity,
+/// This is a less reliable version of [`detect`], but with guaranteed `O(1)` time complexity,
 /// in other words, it takes the same time to check small files and larger files.
 ///
 /// Since different [FileType] detection implementations receives the same data slice, it may produce
 /// more than one matching types.
 ///
-/// This version receives a [variants] parameter that allows to specify which file types to check.
+/// This version receives a `variants` parameter that allows to specify which file types to check.
 pub fn detect_at_start_with_<R>(
     read: &mut R,
     variants: &[FileType],
@@ -367,7 +363,7 @@ where
 /// Since different [FileType] detection implementations receives the same data slice, it may produce
 /// more than one matching types.
 ///
-/// This version receives a [variants] parameter that allows to specify which file types to check.
+/// This version receives a `variants` parameter that allows to specify which file types to check.
 pub fn detect_at_end_with_<R>(
     read: &mut R,
     variants: &[FileType],
@@ -628,6 +624,11 @@ mod tests {
         test_detect_match_maybe("files/rust-logo.bmp", FileType::Bmp);
     }
 
+    #[test]
+    fn test_iso_detect() {
+        test_detect_match("files/test-iso.iso", FileType::Iso);
+    }
+
     #[test]
     fn test_txt_no_match() {
         test_detect_no_match("files/text");
@@ -640,6 +641,21 @@ mod tests {
         test_detect_match("files/test-0.tar", FileType::Tar);
     }
 
+    #[test]
+    fn test_lzma_detect() {
+        test_detect_match("files/test.tar.lzma", FileType::Lzma);
+    }
+
+    #[test]
+    fn test_xz_detect() {
+        test_detect_match("files/test-xz.xz", FileType::Xz);
+    }
+
+    #[test]
+    fn test_zst_detect() {
+        test_detect_match("files/ex.tar.zst", FileType::Zst);
+    }
+
     fn test_detect<P>(path: P) -> Result<Option<FileTypeMatches>, Error>
     where
         P: AsRef<Path>,
@@ -727,6 +743,7 @@ mod tests {
         assert_eq!(detect, expected);
     }
 
+    #[allow(dead_code)]
     fn test_detect_match_sliding<P>(path: P, file_type: FileType) -> ()
     where
         P: AsRef<Path>,
@@ -743,10 +760,10 @@ mod tests {
     #[bench]
     fn bench_multi_detect(b: &mut Bencher) {
         b.iter(|| {
-            detect_rar();
-            detect_zip();
-            detect_jar();
-            detect_png();
+            let _ = detect_rar();
+            let _ = detect_zip();
+            let _ = detect_jar();
+            let _ = detect_png();
         })
     }
 
@@ -765,7 +782,7 @@ mod tests {
         b.iter(|| test_detect("files/hello-world.exe"))
     }
 
-    fn detect_rar() -> Result<(), std::io::Error> {
+    fn detect_rar() -> Result<(), Error> {
         let f = OpenOptions::new()
             .read(true)
             .open("files/hello.rar")
@@ -777,7 +794,7 @@ mod tests {
         Ok(())
     }
 
-    fn detect_png() -> Result<(), std::io::Error> {
+    fn detect_png() -> Result<(), Error> {
         let f = OpenOptions::new()
             .read(true)
             .open("files/rust-logo.png")
@@ -789,7 +806,7 @@ mod tests {
         Ok(())
     }
 
-    fn detect_zip() -> Result<(), std::io::Error> {
+    fn detect_zip() -> Result<(), Error> {
         let f = OpenOptions::new()
             .read(true)
             .open("files/hello.zip")
@@ -801,7 +818,7 @@ mod tests {
         Ok(())
     }
 
-    fn detect_jar() -> Result<(), std::io::Error> {
+    fn detect_jar() -> Result<(), Error> {
         let f = OpenOptions::new()
             .read(true)
             .open("files/hello.jar")
