@@ -1,27 +1,3 @@
-//     bindet - Fast binary file type detection
-//
-//         The MIT License (MIT)
-//
-//      Copyright (c) Obliter Software (https://github.com/oblitersoftware/)
-//      Copyright (c) contributors
-//
-//      Permission is hereby granted, free of charge, to any person obtaining a copy
-//      of this software and associated documentation files (the "Software"), to deal
-//      in the Software without restriction, including without limitation the rights
-//      to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-//      copies of the Software, and to permit persons to whom the Software is
-//      furnished to do so, subject to the following conditions:
-//
-//      The above copyright notice and this permission notice shall be included in
-//      all copies or substantial portions of the Software.
-//
-//      THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-//      IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-//      FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-//      AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-//      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-//      THE SOFTWARE.
 //! Matcher module
 use crate::types::FileType;
 
@@ -121,6 +97,9 @@ impl FileTypeMatcher for FileType {
             FileType::Rar => rar_test(&relative_position, &bytes),
             FileType::Rar5 => rar5_test(&relative_position, &bytes),
             FileType::Tar => tar_test(&relative_position, step, &bytes),
+            FileType::Lzma => lzma_test(&relative_position, step, &bytes),
+            FileType::Xz => xz_test(&relative_position, step, &bytes),
+            FileType::Zst => zst_test(&relative_position, step, &bytes),
             FileType::Png => png_test(&relative_position, step, &bytes),
             FileType::Jpg => jpg_test(&relative_position, step, &bytes),
             FileType::_7z => _7z_test(&relative_position, step, &bytes),
@@ -148,6 +127,7 @@ impl FileTypeMatcher for FileType {
             FileType::Xcf => xcf_test(&relative_position, step, &bytes),
             FileType::Gif => gif_test(&relative_position, step, &bytes),
             FileType::Bmp => bmp_test(&relative_position, step, &bytes),
+            FileType::Iso => iso_test(&relative_position, step, &bytes),
         }
     }
 }
@@ -248,6 +228,70 @@ fn tar_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) ->
     TestResult::NotMatched
 }
 
+const LZMA_MARKER: [u8; 1] = [0x5d];
+const LZMA_LV0_MARKER: &[u8] = &[0x04, 0x00];
+const LZMA_LV1_MARKER: &[u8] = &[0x10, 0x00];
+const LZMA_LV2_MARKER: &[u8] = &[0x20, 0x00];
+const LZMA_LV3_MARKER: &[u8] = &[0x40, 0x00];
+//const LZMA_LV4_MARKER: &[u8] = &[0x40, 0x00];
+const LZMA_LV5_MARKER: &[u8] = &[0x80, 0x00];
+//const LZMA_LV6_MARKER: &[u8] = &[0x80, 0x00];
+const LZMA_LV7_MARKER: &[u8] = &[0x00, 0x01];
+const LZMA_LV8_MARKER: &[u8] = &[0x00, 0x02];
+const LZMA_LV9_MARKER: &[u8] = &[0x00, 0x04];
+fn lzma_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start {
+        if *step == Step::Small {
+            if bytes.len() >= 1 {
+                let slice = &bytes[0..1];
+                if slice == LZMA_MARKER {
+                    return TestResult::Matched;
+                }
+            }
+        } else {
+            if bytes.len() >= 5 {
+                let slice = &bytes[0..5];
+                if &slice[0..1] == LZMA_MARKER {
+                    match &slice[3..5] {
+                        LZMA_LV0_MARKER | LZMA_LV1_MARKER | LZMA_LV2_MARKER | LZMA_LV3_MARKER
+                        | LZMA_LV5_MARKER | LZMA_LV7_MARKER | LZMA_LV8_MARKER | LZMA_LV9_MARKER => {
+                            return TestResult::Matched
+                        }
+                        _ => {}
+                    }
+                }
+            }
+        }
+    }
+    TestResult::NotMatched
+}
+
+const XZ_MARKER: [u8; 5] = [0xfd, 0x37, 0x7a, 0x58, 0x5a];
+fn xz_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        if bytes.len() >= 5 {
+            let slice = &bytes[0..5];
+            if slice == XZ_MARKER {
+                return TestResult::Matched;
+            }
+        }
+    }
+    TestResult::NotMatched
+}
+
+const ZST_MARKER: [u8; 4] = [0x28, 0xb5, 0x2f, 0xfd];
+fn zst_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        if bytes.len() >= 4 {
+            let slice = &bytes[0..4];
+            if slice == ZST_MARKER {
+                return TestResult::Matched;
+            }
+        }
+    }
+    TestResult::NotMatched
+}
+
 const PNG_SIGNATURE: [u8; 8] = [0x89, 0x50, 0x4e, 0x47, 0x0D, 0x0A, 0x1A, 0x0A];
 fn png_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
     if *relative_position == RelativePosition::Start && *step == Step::Small {
@@ -530,6 +574,17 @@ fn bmp_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) ->
     return TestResult::NotMatched;
 }
 
+const ISO_SIGNATURE_1: [u8; 5] = [0x43, 0x44, 0x30, 0x30, 0x31];
+fn iso_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Large {
+        if bytes.len() >= 32769 {
+            return slice_test(&bytes[32769..], &ISO_SIGNATURE_1);
+        }
+    }
+
+    return TestResult::NotMatched;
+}
+
 fn slice_test(bytes: &[u8], matching: &[u8]) -> TestResult {
     if bytes.len() >= matching.len() {
         if &bytes[..matching.len()] == matching {
