@@ -1,31 +1,20 @@
-//     bindet - Fast binary file type detection
-//
-//         The MIT License (MIT)
-//
-//      Copyright (c) Obliter Software (https://github.com/oblitersoftware/)
-//      Copyright (c) contributors
-//
-//      Permission is hereby granted, free of charge, to any person obtaining a copy
-//      of this software and associated documentation files (the "Software"), to deal
-//      in the Software without restriction, including without limitation the rights
-//      to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-//      copies of the Software, and to permit persons to whom the Software is
-//      furnished to do so, subject to the following conditions:
-//
-//      The above copyright notice and this permission notice shall be included in
-//      all copies or substantial portions of the Software.
-//
-//      THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-//      IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-//      FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-//      AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-//      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-//      THE SOFTWARE.
-//! File Type module
+//! Enumerates all file types that **bindet** is able to detect.
+//!
+//! Those enumerations are separated in two:
+//!
+//! - [FileType]
+//! - [FileRootType]
 
-/// FileType
+/// All file types that **bindet** is able to detect, some of them are just different versions
+/// of the same format or very similar.
+///
+/// **bindet** is able to do both, refined detection, which it tries to detect [FileType] precisely,
+/// and general detection, which it tries to do a weaker [FileType] detection
+/// (**note**: in its current state, it is only doing the precise detection).
+///
+/// A more general categorization is enumerated by [FileRootType].
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
+#[non_exhaustive]
 pub enum FileType {
     /// Zip File format, this includes:
     /// - jar
@@ -36,8 +25,17 @@ pub enum FileType {
     Zip,
     Rar,
     Rar5,
-    /// Tar archive (regardless the compression)
+    /// Tar archive (only uncompressed).
+    ///
+    /// Compressed tar archives are first archived using tar, then
+    /// compressed, which means that in order to detect compressed tar
+    /// files we need to decompress them first, which is not viable
+    /// for this library, and is not part of its goal.
+    ///
     Tar,
+    Lzma,
+    Xz,
+    Zst,
     Png,
     Jpg,
     _7z,
@@ -101,16 +99,21 @@ pub enum FileType {
     Gif,
     /// Bitmap
     Bmp,
+    /// Optical Disc Image
+    Iso,
 }
 
 impl FileType {
     /// Gets all variants of [FileType]
-    pub fn variants() -> [FileType; 31] {
+    pub fn variants() -> [FileType; 35] {
         [
             FileType::Zip,
             FileType::Rar,
             FileType::Rar5,
             FileType::Tar,
+            FileType::Lzma,
+            FileType::Xz,
+            FileType::Zst,
             FileType::Png,
             FileType::Jpg,
             FileType::_7z,
@@ -138,6 +141,7 @@ impl FileType {
             FileType::Xcf,
             FileType::Gif,
             FileType::Bmp,
+            FileType::Iso,
         ]
     }
 
@@ -147,11 +151,13 @@ impl FileType {
             FileType::Zip => FileRootType::Zip,
             FileType::Rar | FileType::Rar5 => FileRootType::Rar,
             FileType::Tar => FileRootType::Tar,
+            FileType::Lzma => FileRootType::Lzma,
+            FileType::Xz => FileRootType::Xz,
+            FileType::Zst => FileRootType::Zst,
             FileType::Png => FileRootType::Png,
             FileType::Jpg => FileRootType::Jpg,
             FileType::_7z => FileRootType::_7z,
-            FileType::Opus => FileRootType::Ogg,
-            FileType::Vorbis => FileRootType::Ogg,
+            FileType::Opus | FileType::Vorbis => FileRootType::Ogg,
             FileType::Mp3 => FileRootType::Mp3,
             FileType::Webp => FileRootType::Webp,
             FileType::Flac => FileRootType::Flac,
@@ -169,21 +175,31 @@ impl FileType {
             FileType::Ico => FileRootType::Ico,
             FileType::Dalvik => FileRootType::Dalvik,
             FileType::Pdf => FileRootType::Pdf,
-            FileType::DosMzExecutable => FileRootType::DosExecutable,
-            FileType::DosZmExecutable => FileRootType::DosExecutable,
+            FileType::DosMzExecutable | FileType::DosZmExecutable => FileRootType::DosExecutable,
             FileType::Xcf => FileRootType::Xcf,
             FileType::Gif => FileRootType::Gif,
             FileType::Bmp => FileRootType::Bmp,
+            FileType::Iso => FileRootType::Iso,
         }
     }
 }
 
+/// Root file type which categorizes types in a generic way.
 ///
+/// For example, `Rar` and `Rar5` are both in the same `Rar` category, the same as
+/// `DosMzExecutable` and `DosZmExecutable`, which are in the `DosExecutable` category.
+///
+/// This is useful when you are interested in knowing the type of a file, but does not need
+/// much precision.
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
+#[non_exhaustive]
 pub enum FileRootType {
     Zip,
     Rar,
     Tar,
+    Lzma,
+    Xz, // XZ and LZMA in the same category?? I don't really know because LZMA is really old
+    Zst,
     Png,
     Jpg,
     _7z,
@@ -209,4 +225,11 @@ pub enum FileRootType {
     Xcf,
     Gif,
     Bmp,
+    Iso,
+}
+
+impl From<FileType> for FileRootType {
+    fn from(file_type: FileType) -> Self {
+        file_type.root()
+    }
 }
